@@ -35,6 +35,7 @@ class LambdaFunction(Resource):
         "EphemeralStorage": GeneratedProperty(),
         "RuntimeManagementConfig": GeneratedProperty(),
         "LoggingConfig": GeneratedProperty(),
+        "RecursiveLoop": GeneratedProperty(),
     }
 
     Code: Dict[str, Any]
@@ -62,6 +63,7 @@ class LambdaFunction(Resource):
     EphemeralStorage: Optional[Dict[str, Any]]
     RuntimeManagementConfig: Optional[Dict[str, Any]]
     LoggingConfig: Optional[Dict[str, Any]]
+    RecursiveLoop: Optional[str]
 
     runtime_attrs = {"name": lambda self: ref(self.logical_id), "arn": lambda self: fnGetAtt(self.logical_id, "Arn")}
 
@@ -116,9 +118,12 @@ class LambdaEventSourceMapping(Resource):
         "FunctionResponseTypes": GeneratedProperty(),
         "SelfManagedEventSource": GeneratedProperty(),
         "FilterCriteria": GeneratedProperty(),
+        "KmsKeyArn": GeneratedProperty(),
         "AmazonManagedKafkaEventSourceConfig": GeneratedProperty(),
         "SelfManagedKafkaEventSourceConfig": GeneratedProperty(),
         "ScalingConfig": GeneratedProperty(),
+        "ProvisionedPollerConfig": GeneratedProperty(),
+        "MetricsConfig": GeneratedProperty(),
     }
 
     runtime_attrs = {"name": lambda self: ref(self.logical_id)}
@@ -134,6 +139,7 @@ class LambdaPermission(Resource):
         "SourceArn": GeneratedProperty(),
         "EventSourceToken": GeneratedProperty(),
         "FunctionUrlAuthType": GeneratedProperty(),
+        "InvokedViaFunctionUrl": GeneratedProperty(),
     }
 
 
